@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# Copyright (C) 2011, Antonio Valentino <antonio.valentino@tiscali.it>
+# Copyright (C) 2011-2012, Antonio Valentino <antonio.valentino@tiscali.it>
 #
 # This file is part of PyEPR.
 #
@@ -120,9 +120,18 @@ class TestOpenProduct(unittest.TestCase):
     def test_open_failure(self):
         self.assertRaises(ValueError, epr.open, '')
 
+    def test_filename_type(self):
+        self.assertRaises(TypeError, epr.open, 3)
+
+    def test_open_failure_invalid_product(self):
+        self.assertRaises(ValueError, epr.open, __file__)
+
     def test_product_constructor_failure(self):
         self.assertRaises(ValueError, epr.Product, '')
 
+    def test_product_constructor_failure_invalid_product(self):
+        self.assertRaises(ValueError, epr.Product, __file__)
+
 
 class TestProduct(unittest.TestCase):
     PRODUCT_FILE = os.path.join(TESTDIR, TEST_PRODUCT)
@@ -1587,4 +1596,7 @@ class TestLibVersion(unittest.TestCase):
 
 
 if __name__ == '__main__':
+    print('PyEPR: %s' % epr.__version__)
+    print('EPR API: %s' % epr.EPR_C_API_VERSION)
+    print('Python: %s' % sys.version)
     unittest.main()
